This crate contains kube-rs compatible bindings for Kubernetes custom resources for the kuadrant.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
kuadrant.io/v1
AuthPolicyRateLimitPolicy
kuadrant.io/v1alpha1
DNSHealthCheckProbeDNSRecordManagedZone
kuadrant.io/v1beta1
Kuadrant
kuadrant.io/v1beta2
AuthPolicyRateLimitPolicy
kuadrant.io/v1beta3
AuthPolicyRateLimitPolicy